Hedwig
======

django.core.mail provides a nice interface to sending/testing email via various
backends including SMTP. Unfortunately, it's distributed under django project.

This, Hedwig, is a copy of django.core.mail. All interfaces will be
compatible with django.core.mail, but implemenation could be different.
